@@ -1,3 +1,3 @@
 #!/bin/bash
 python setup.py sdist upload
-python setup.py bdist upload
+#python setup.py bdist upload
